#ifndef PIX_H
#define PIX_H

#include "gfxinterface.h"
#include <map>


// Picture defined by two pixmaps: one for colors; one for tranparency (shape).
// The constructors loads it in the X server and it can then displayed an
// arbitrary number of times.
class Pix {
	Pix(const Pix &); // no copy
	Pix & operator=(const Pix &); // no assign

	Pixmap pixmap_, shapemask_;
	XpmAttributes attrs_;
public:
	Pix(const char ** xpm);
	~Pix();
	int Width()  const { return attrs_.width;  }
	int Height() const { return attrs_.height; }
	void Draw(Coord pos) const;
	void Erase(Coord pos) const;
};


// Singleton that initializes and keep Pix's.
class PixKeeper {
	static PixKeeper * singleton_;

	PixKeeper() {}
	~PixKeeper();
	PixKeeper(const PixKeeper &); // no copy
	PixKeeper & operator=(const PixKeeper &); // no copy

	typedef std::map<const char **, Pix *> PixCtr;
	PixCtr pixes_;
public:
	static PixKeeper & Instance()
	{
		if (!singleton_) singleton_ = new PixKeeper;
		return *singleton_;
	}
	static void DestroyInstance() { delete singleton_; singleton_ = 0; }

	Pix * Get(const char ** pix_data);
};


#endif
